@@ -100,7 +100,7 @@
         if (is.null(parallel))
             parallel <- 1
         hasClus <- inherits(parallel, "cluster")
-        isParal <- (hasClus || parallel > 1) && require(parallel)
+        isParal <- hasClus || parallel > 1
         isMulticore <- .Platform$OS.type == "unix" && !hasClus
         if (isParal && !isMulticore && !hasClus) {
             parallel <- makeCluster(parallel)
