@@ -46,11 +46,12 @@
         if (is.null(parallel))
             parallel <- 1
         hasClus <- inherits(parallel, "cluster")
-        if ((hasClus || parallel > 1)  && require(parallel)) {
+        if (hasClus || parallel > 1) {
             if(.Platform$OS.type == "unix" && !hasClus) {
-                perm <- unlist(mclapply(1:permutations, function(i, ...)
-                                        ptest(permat[i,]),
-                                        mc.cores = parallel))
+                perm <- unlist(mclapply(1:permutations,
+                                                  function(i, ...)
+                                                  ptest(permat[i,]),
+                                                  mc.cores = parallel))
             } else {
                 if (!hasClus) {
                     parallel <- makeCluster(parallel)
