@@ -1,4 +1,4 @@
-"vegemite" <-
+`vegemite` <-
     function (x, use, scale, sp.ind = NULL, site.ind = NULL, zero = ".", 
               select, ...) 
 {
@@ -9,7 +9,10 @@
             if (is.null(sp.ind)) 
                 sp.ind <- order(wascores(use, x))
         }
-        else if (inherits(use, "hclust")) {
+        else if (inherits(use, c("hclust", "twins"))) {
+            if (inherits(use, "twins")) {
+                use <- as.hclust(use)
+            }
             if (is.null(site.ind)) 
                 site.ind <- use$order
             if (is.null(sp.ind)) 
